@@ -88,6 +88,7 @@ struct ProcConfig
     gint        height;
     gint        xpos;
     gint        ypos;
+    gboolean    maximized;
     gboolean    show_kill_warning;
     gboolean    show_tree;
     gboolean    show_all_fs;
@@ -96,13 +97,13 @@ struct ProcConfig
     int         disks_update_interval;
     gint        whose_process;
     gint        current_tab;
-    GdkColor    cpu_color[GLIBTOP_NCPU];
-    GdkColor    mem_color;
-    GdkColor    swap_color;
-    GdkColor    net_in_color;
-    GdkColor    net_out_color;
-    GdkColor    bg_color;
-    GdkColor    frame_color;
+    GdkRGBA     cpu_color[GLIBTOP_NCPU];
+    GdkRGBA     mem_color;
+    GdkRGBA     swap_color;
+    GdkRGBA     net_in_color;
+    GdkRGBA     net_out_color;
+    GdkRGBA     bg_color;
+    GdkRGBA     frame_color;
     gint        num_cpus;
     bool solaris_mode;
     bool network_in_bits;
@@ -189,8 +190,8 @@ class ProcInfo
 
     gchar        *security_context;
 
-    const guint    pid;
-    guint        ppid;
+    const pid_t    pid;
+    pid_t        ppid;
     guint        uid;
 
 // private:
