@@ -24,17 +24,12 @@
 #include <glibtop/procmem.h>
 #include <glibtop/procmap.h>
 #include <glibtop/procstate.h>
-#if defined (__linux__)
-#include <asm/param.h>
-#elif defined (__NetBSD__) || defined (__OpenBSD__)
-#include <sys/param.h>
-#include <sys/sysctl.h>
-#endif
 
 #include "procman.h"
 #include "procproperties.h"
 #include "proctable.h"
 #include "util.h"
+#include "e_date.h"
 
 enum
 {
@@ -117,18 +112,6 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
 
     get_process_memory_info(info);
 
-#if defined (__NetBSD__) || defined (__OpenBSD__)
-    struct clockinfo cinf;
-    size_t size = sizeof (cinf);
-    int HZ;
-    int mib[] = { CTL_KERN, KERN_CLOCKRATE };
-
-    if (sysctl (mib, G_N_ELEMENTS (mib), &cinf, &size, NULL, 0) == -1)
-        HZ = 100;
-    else
-        HZ = cinf.hz;
-#endif
-
     proc_arg proc_props[] = {
         { N_("Process Name"), g_strdup_printf("%s", info->name)},
         { N_("User"), g_strdup_printf("%s (%d)", info->user.c_str(), info->uid)},
@@ -140,14 +123,15 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
         { N_("Shared Memory"), format_memsize(info->memshared)},
         { N_("X Server Memory"), format_memsize(info->memxserver)},
         { N_("CPU"), g_strdup_printf("%d%%", info->pcpu)},
-        { N_("CPU Time"), g_strdup_printf(ngettext("%lld second", "%lld seconds", info->cpu_time/HZ), (unsigned long long)info->cpu_time/HZ) },
-        { N_("Started"), g_strdup_printf("%s", ctime((const time_t*)(&info->start_time)))},
+        { N_("CPU Time"), procman::format_duration_for_display(100 * info->cpu_time / ProcData::get_instance()->frequency) },
+        { N_("Started"), procman_format_date_for_display(info->start_time) },
         { N_("Nice"), g_strdup_printf("%d", info->nice)},
         { N_("Priority"), g_strdup_printf("%s", procman::get_nice_level(info->nice)) },
         { N_("ID"), g_strdup_printf("%d", info->pid)},
-        { N_("Security Context"), g_strdup_printf("%s", info->security_context)},
+        { N_("Security Context"), info->security_context ? g_strdup_printf("%s", info->security_context) : g_strdup(_("N/A"))},
         { N_("Command Line"), g_strdup_printf("%s", info->arguments)},
         { N_("Waiting Channel"), g_strdup_printf("%s", info->wchan)},
+        { N_("Control Group"), info->cgroup_name ? g_strdup_printf("%s", info->cgroup_name) : g_strdup(_("N/A"))},
         { NULL, NULL}
     };
 
@@ -203,7 +187,6 @@ create_procproperties_tree (ProcData *procdata)
         );
 
     tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree), TRUE);
     g_object_unref (G_OBJECT (model));
 
     for (i = 0; i < NUM_COLS; i++) {
@@ -268,11 +251,11 @@ create_single_procproperties_dialog (GtkTreeModel *model, GtkTreePath *path,
     gtk_box_set_spacing (GTK_BOX (vbox), 2);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
-    dialog_vbox = gtk_vbox_new (FALSE, 6);
+    dialog_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 5);
     gtk_box_pack_start (GTK_BOX (vbox), dialog_vbox, TRUE, TRUE, 0);
 
-    cmd_hbox = gtk_hbox_new (FALSE, 12);
+    cmd_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (dialog_vbox), cmd_hbox, FALSE, FALSE, 0);
 
     label = procman_make_label_for_mmaps_or_ofiles (
