@@ -485,7 +485,7 @@ namespace {
             if (error)
                 g_error_free(error);
 
-                g_free(out);
+            g_free(out);
         }
 
     private:
@@ -709,11 +709,7 @@ add_row(GtkGrid * table, const char * label, const char * value, int row)
     gtk_label_set_markup(GTK_LABEL(header), label);
     gtk_label_set_selectable(GTK_LABEL(header), TRUE);
     gtk_widget_set_can_focus(header, FALSE);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (header), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
-#endif
     gtk_grid_attach(
         table, header,
         0, row, 1, 1);
@@ -721,11 +717,7 @@ add_row(GtkGrid * table, const char * label, const char * value, int row)
     GtkWidget *label_widget = gtk_label_new(value);
     gtk_label_set_selectable(GTK_LABEL(label_widget), TRUE);
     gtk_widget_set_can_focus(label_widget, FALSE);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label_widget), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label_widget), 0.0, 0.5);
-#endif
     gtk_grid_attach(
         table, label_widget,
         1, row, 1, 1);
@@ -805,11 +797,7 @@ procman_create_sysinfo_view(void)
     distro_release_label = gtk_label_new("???");
     gtk_label_set_selectable(GTK_LABEL(distro_release_label), TRUE);
     gtk_widget_set_can_focus(distro_release_label, FALSE);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (distro_release_label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (distro_release_label), 0.0, 0.5);
-#endif
     gtk_grid_attach(
         GTK_GRID(distro_table), distro_release_label,
         0, table_count, 1, 1);
@@ -821,11 +809,7 @@ procman_create_sysinfo_view(void)
     gtk_label_set_selectable(GTK_LABEL(header), TRUE);
     gtk_widget_set_can_focus(header, FALSE);
     g_free(markup);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (header), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
-#endif
     gtk_grid_attach(
         GTK_GRID(distro_table), header,
         0, table_count, 1, 1);
@@ -838,11 +822,7 @@ procman_create_sysinfo_view(void)
         gtk_label_set_selectable(GTK_LABEL(header), TRUE);
         gtk_widget_set_can_focus(header, FALSE);
         g_free(markup);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (header), 0.0);
-#else
-        gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
-#endif
         gtk_grid_attach(
             GTK_GRID(distro_table), header,
             0, table_count, 1, 1);
